package organizer.components;

import nextapp.echo2.app.Button;
import nextapp.echo2.app.Extent;
import nextapp.echo2.app.Grid;
import nextapp.echo2.app.Label;
import nextapp.echo2.app.Row;
import nextapp.echo2.app.SplitPane;
import nextapp.echo2.app.TextArea;
import nextapp.echo2.app.TextField;
import nextapp.echo2.app.WindowPane;
import nextapp.echo2.extras.app.TabPane;
import nextapp.echo2.extras.app.layout.TabPaneLayoutData;

import organizer.images.Images;
import organizer.messages.Messages;

/**
 * Trieda AddWindow predstavuje okno pomocou, ktor vkladme do programu lohu.
 */
public class AddWindow  extends WindowPane
{
	/**
	 * Bezparametrick kontruktor triedy AddWindow. V kontruktore nastavme zkladn
	 * vlastnosti okna. Vetko nastavujeme pomocou tlom okrem vekosti, lebo t sa 
	 * z okna na okno me zmeni. Oknu nastavujeme rune aj jeho modalnos. Modlnos
	 * znamen, e okno preberie ,,kontrolu" nad aplikcia take pokia je otvoren nie je
	 * mon klikn inde. Modlnos nie je mone nastavi cez tly.
	 * Po nastaven vlastnost okna pridme zloky.
	 * 
	 */
	public AddWindow()
	{
		// Vekost okna zadvame dynamicky. 
		setWidth(new Extent(600));
		setHeight(new Extent(400));
		setStyleName("Window");
		setModal(true);
		// Vytvorme zloky
		TabPane pane = new TabPane();
		pane.setStyleName("AddWindowPane");
		pane.add(createMeetingTab());
			
		add(pane);
	}
	
	/**
	 * Metda vytvra zloku pre stretnutie. Zloke nastavme nadpis pomocou triedy
	 * TabPaneLayoutData a jej metdy setTitle. Nsledne vytvorme jednotliv komponenty,
	 * tie pridme do objektu triedy Grid. Trieda Grid m samovysvetlujci nzov - je to 
	 * jednoducho mrieka. Do tejto mrieky postupne pridvame komponenty.
	 * Tto mrieku spolu s odosielacm tlaidlom vlome do objektu SplitPane, ktor metda
	 * vrti. 
	 * 
	 * @return Objekt triedy SplitPane naplnen potrebnmi komponentami.
	 */
	public SplitPane createMeetingTab()
	{
		// Vytvorme SplitPane
		SplitPane meetingPane = new SplitPane(SplitPane.ORIENTATION_VERTICAL_BOTTOM_TOP,new Extent(30));
		// Objektom layout nastavme nzov zloky.
		TabPaneLayoutData layout = new TabPaneLayoutData();
		layout.setTitle(Messages.getMessage("AddWindow.Meeting"));
		meetingPane.setLayoutData(layout);
		/*==========================VYTVRANIE KOMPONENTOV==========================*/
		// Mrieka, do ktorej sa pridaj vektky komponenty
		Grid grid = new Grid();
		grid.setStyleName("Grid");
		// TextField pre predmet
		TextField subjectField = new TextField();
		subjectField.setStyleName("InputField");
		// TextField pre miesto
		TextField placeField = new TextField();
		placeField.setStyleName("InputField");
		// TextField pre zaiaton dtum
		TextField startField = new TextField();
		startField.setStyleName("InputField");
		// TextField pre koneny dtum
		TextField endField = new TextField();
		endField.setStyleName("InputField");
		// TextArea pre poznmky
		TextArea notesArea = new TextArea();
		notesArea.setStyleName("TextArea");
		// Label pre predmet		
		Label subjectLabel = new Label(Messages.getMessage("MeetingTab.Subject"));
		subjectLabel.setStyleName("InputLabel");
		// Label pre miesto
		Label placeLabel = new Label(Messages.getMessage("MeetingTab.Place"));
		placeLabel.setStyleName("InputLabel");
		// Label pre zaiaton dtum
		Label startLabel = new Label(Messages.getMessage("MeetingTab.Start"));
		startLabel.setStyleName("InputLabel");
		// Label pre koneny dtum
		Label endLabel = new Label(Messages.getMessage("MeetingTab.End"));
		endLabel.setStyleName("InputLabel");
		// Label pre poznmky
		Label noteLabel = new Label(Messages.getMessage("MeetingTab.Note"));
		noteLabel.setStyleName("InputLabel");
		// Odosielacie tlaidlo
		Button submitButton = new Button();
		submitButton.setIcon(Images.SUBMIT_BUTTON);
		// Riadok pre odosielacie tlaidlo
		Row buttonRow = new Row();
		buttonRow.setStyleName("SubmitButtonRow");
		/*==========================PRIDVANIE KOMPONENTOV==========================*/
		// Riadok pre odosielacie tlaidlo
		buttonRow.add(submitButton);
		// Komponenty pridme do mrieky	
		// 1. Riadok
		grid.add(subjectLabel);
		grid.add(subjectField);
		// 2. Riadok
		grid.add(placeLabel);
		grid.add(placeField);
		// 3. Riadok
		grid.add(startLabel);
		grid.add(startField);
		// 4. Riadok
		grid.add(endLabel);
		grid.add(endField);
		// 5. Riadok
		grid.add(noteLabel);
		grid.add(notesArea);
		// Do objektu SplitPane vlome najrpv riadok s tlaidlom a potom mrieku
		meetingPane.add(buttonRow);
		meetingPane.add(grid);
		
		return meetingPane;
	}
}
